import styles from './article.module.scss'
import {useTranslation} from "react-i18next";
import {Input, Switch} from "antd";
import {useMemo} from "react";

type HotNewsProps = {
	news: string[];
	mode: string;
	onValueChange: (values: {
		news: string[],
		mode: string
	}) => void;
}


function HotNews({news, mode, onValueChange}: HotNewsProps) {
	const {t,i18n} = useTranslation()
	const demoPlaceholderList = useMemo(()=>{
		return i18n.language == 'zh-CN' ? [
			'例：韩正会见英国汇丰集团主席',
			'例: 丁薛祥出席全国高校毕业生等青年就业创业工作视频...',
			'例：俄称乌方再度袭击俄能源设施 乌称击退俄军进攻',
		] : [
			'eg.China\'s tax policies invigorate private economy',
			'eg.China\'s central bank conducts reverse repos Wednesday',
			'eg.China intensifies law enforcement in cyberspace',
		]
	},[i18n.language])
	const handleValueChange = (value: string, index: number) => {
		const values = [...news]
		values[index] = value
		onValueChange({news: values, mode})
	}
	return (
		<div className={`${styles.hotNews} mt-3`}>
			<div className="flex justify-between">
				<div className="area-title">
				<span className="title">{t("modal.hot_news.title")}</span>
				</div>
				<div className="mode">
					<span className="mr-2">{mode == 'auto' ? t("modal.hot_news.edit_auto") : t("modal.hot_news.edit_manual")}</span>
					<Switch size="small" checked={mode != 'auto'} onChange={checked => {
						onValueChange({news, mode: checked ? 'manual' : 'auto'})
					}}/>
				</div>
			</div>
			{mode != 'auto' && <div className="hot-news-list panel-body p-3 ">
				{news.map((item, index) => <div key={index} className={`hot-news-item bg-gray-50 ${index == 0?'':'mt-3'} rounded-xl`}>
					<Input
						variant={"borderless"}
						readOnly={mode == 'auto'}
						placeholder={mode != 'auto' ? demoPlaceholderList[index] : ''}
						value={item}
						onChange={e => handleValueChange(e.target.value, index)}/>
				</div>)}
      </div>}
		</div>
	)
}

export default HotNews