import {Divider, Input, message} from "antd"
import ArticleBlock from "@/components/article/block.tsx";

import styles from './article.module.scss'
import {showToast} from "@/components/message.ts";
import React from "react";
import {useTranslation} from "react-i18next";
import {IconAdd} from "@/components/icons";
import HotNews from "@/components/article/HotNews.tsx";

export type HotNewsData = {
	list: string[];
	mode: string
}
type Props = {
	groups: BlockContent[][];
	editable?: boolean;
	onChange?: (groups: BlockContent[][], hotNews: HotNewsData) => void;
	errorMessage?: string;
	hotNews: HotNewsData;
	leftPanelHeader?: React.ReactNode;
}


export default function ArticleGroup({groups, editable, onChange, errorMessage, hotNews, leftPanelHeader}: Props) {
	const {t, i18n} = useTranslation()
	// const groups = rebuildGroups(_groups)
	/**
	 * 添加一个组
	 * @param insertIndex 插入的位置，-1表示插入到末尾
	 */
	const handleAddGroup = (insertIndex: number, checkId: number) => {
		// && insertIndex !== 1
		if (checkId > 0 && checkId < groups.length) {
			//const index = insertIndex == -1 || insertIndex >= groups.length ? groups.length - 1 : insertIndex - 1
			const triggerGroup = groups[checkId];
			// 判断
			if (!triggerGroup || triggerGroup.length == 0 || triggerGroup.some(s => !s.content)) {
				showToast(t('news.edit_notice_enter_text'))
				return;
			}
		}

		const newGroup: BlockContent[] = [{type: 'text', content: ''}]
		const _groups = [...groups];
		if (insertIndex == -1 || insertIndex >= groups.length) { // -1或者越界表示新增
			_groups.push(newGroup)
		} else {
			_groups.splice(insertIndex, 0, newGroup)
		}
		onChange?.(_groups, hotNews)
	}

	const handleDigitalPersonContentChange = (content: string) => {
		groups[0] = [{type: 'text', content}]
		onChange?.([...groups], hotNews)
	}

	return <div className={styles.group}>
		<div className={'panel digital-person h-[544px]'}>
			{leftPanelHeader}
			<div className="area-title">
				<span className="">{t('news.edit_digital_text')}</span>
				{i18n.language == 'zh-CN' && <span className="text-gray-400">（出现数字人形象）</span>}
			</div>
			<div className="panel-body p-3 flex-1 main-human-text">
				{/* value={groups || groups[0][0].content}*/}
				<div className={`h-full rounded-xl overflow-hidden bg-gray-50`}>
					<div className="human-tts h-full">
						{editable ? <div className="relative h-full">
							<Input.TextArea
								placeholder={t('news.edit_notice_enter_text')}
								className="main-human-text-input"
								value={groups && groups.length > 0 ? groups[0][0].content : ''}
								autoSize={{maxRows: hotNews.mode == 'auto'?15:8}}
								variant={"borderless"}
								onChange={e => {
									handleDigitalPersonContentChange(e.target.value)
								}}
							/>
						</div> : <p className="p-2">{groups && groups.length > 0 ? groups[0][0].content : ''}</p>}
					</div>
				</div>
			</div>
			<div className="hot-news-container">
				<HotNews
					news={hotNews.list} mode={hotNews.mode}
					onValueChange={(hotNews) => {
						onChange?.([...groups], {
							list:hotNews.news,mode: hotNews.mode
						})
					}}/>
			</div>
		</div>
		<div className={"panel groups-list flex-1"}>
			<div className={"area-title"}>
				<span className="">{t('news.edit_other_text')}</span>
				{i18n.language == 'zh-CN' && <span className="text-gray-400">（文、图、视频，不出现数字人形象）</span>}
			</div>

			<div className="panel-body py-3">
				<div className="max-h-[485px] overflow-auto py-4">

					{editable && groups.length == 1 && <div className={`${styles.blockContainer} group`}>
              <div className={'divider-container before'}><Divider>
                  <span onClick={() => handleAddGroup?.(1, 1)} className="article-action-add"
                        title={t('news.materials.add_group')}><IconAdd style={{fontSize: 24}}/></span>
              </Divider></div>
          </div>}

					{groups.map((g, index) => (
						index == 0 ? null : <ArticleBlock
							editable={editable}
							key={index}
							blocks={g}
							onChange={(blocks) => {
								groups[index] = blocks
								onChange?.([...groups], hotNews)
							}}
							errorMessage={errorMessage}
							index={index}
							onAdd={(_index, checkIndex) => {
								handleAddGroup?.(_index ? _index : index + 1, checkIndex)
							}}
							disableRemoveMessage={groups.length <= 1 ? t('news.edit_notice_keep_1') : ''}
							onRemove={async () => {
								if (groups.length <= 1) {
									message.warning(t('news.edit_notice_keep_1'))
									return;
								}
								onChange?.(groups.filter((_, idx) => index !== idx), hotNews)
							}}
						/>
					))}
				</div>
			</div>
		</div>
		{groups.length == 0 && editable &&
        <ArticleBlock editable onChange={blocks => onChange?.([blocks],hotNews)} index={0}
                      blocks={[{type: 'text', content: ''}]}/>}
	</div>
}