import React, {useMemo} from "react";
import {isRouteErrorResponse, useNavigate, useRouteError} from 'react-router-dom';
import {Button} from "antd";

import error500 from "@/assets/images/error/Error500.png";
import {useTranslation} from "react-i18next";
// ==============================|| ELEMENT ERROR - COMMON ||============================== //
const ErrorBoundary: React.FC<{
	minHeight?: string | number;
	errorCode?: 401 | 404 | 503
}> = ({errorCode}) => {
	const {t, i18n} = useTranslation()
	const error = useRouteError() as Error;
	console.log(error)
	const errorMessage = useMemo(() => {
		let _message = t('error_500')
		const errorConfig: {
			[key: number]: string
		} = {
			401: t('error_401'),
			403: t('error_403'),
			404: t('error_404'),
			500: t('error_500'),
		}
		if (isRouteErrorResponse(error)) {
			if (errorConfig[error.status]) {
				_message = `Error ${error.status} - ${errorConfig[error.status]}`;
			}
		}
		if (errorCode) {
			if (errorConfig[errorCode]) {
				_message = `Error ${errorCode} - ${errorConfig[errorCode]}`;
			}
		}
		return _message
	}, [i18n, errorCode])
	const navigate = useNavigate()
	const handleGoBack = () => {
		navigate('/')
	}
	return (<div className="max-w-screen-lg mx-auto flex justify-center items-center h-screen">
		<div className={'flex flex-row items-center'}>
			<div className="flex-col">
				<div className="sm:w-396px">
					<img src={error500} alt="error" className="w-full"/>
				</div>
			</div>
			<div className="flex-col md:w-full ml-20">
				<div className="text-center">
					<div className="text-3xl">
						Internal Server Error
					</div>
					<div className="text-gray-400 my-5">
						{errorMessage}
					</div>
					{process.env.NODE_ENV == 'development' && error && <div>
                        <pre style={{
	                        font: 'inherit',
	                        textAlign: 'left',
	                        maxWidth: 700,
	                        marginTop: 20,
	                        maxHeight: 300,
	                        overflow: 'auto'
                        }}>
                            <code style={{
	                            wordBreak: 'break-all',
	                            font: 'inherit',
	                            whiteSpace: 'break-spaces'
                            }}>{error.stack}</code>
                        </pre>
          </div>}
					<div className="flex flex-grow gap-2 mt-10 justify-center">
						<Button type='primary' className="px-5" onClick={handleGoBack}>
							<h1>{t('go_to_home')}</h1>
						</Button>
					</div>
				</div>
			</div>
		</div>
	</div>);
};

export default ErrorBoundary;
