import {createBrowserRouter, RouterProvider,} from "react-router-dom";
import React, {Suspense, useEffect,} from "react";
import {ConfigProvider, App, Modal} from "antd";
import zhCN from 'antd/locale/zh_CN';
// for date-picker i18n
import dayjs from "dayjs";
import 'dayjs/locale/zh-cn';
import ErrorBoundary from "./error.tsx";
import Loader from "@/components/loader.tsx";
import routes from "@/routes/routes.tsx";
import {DocumentTitle} from "@/components/document.tsx";
import {useTranslation} from "react-i18next";
import useGlobalConfig from "@/hooks/useGlobalConfig.ts";
import {getRemainingDuration} from "@/service/api/order.ts";
import ModalWarning from "@/components/icons/ModalWarning.tsx";


const router = createBrowserRouter([
	...routes,
	{path: '*', element: <ErrorBoundary errorCode={404}/>}
], {
	basename: import.meta.env.VITE_APP_BASE_NAME,
	future: {
		v7_fetcherPersist: true,
		v7_relativeSplatPath: true,
		v7_normalizeFormMethod: true,
		v7_skipActionErrorRevalidation: true,
		v7_partialHydration: true,
	}
})

// future={{v7_startTransition: true,v7_relativeSplatPath: true}}
const AppRouter = () => {
	const {globalConfig} = useGlobalConfig();
	const {t,i18n} = useTranslation();

	const initRemainingDuration = () => {
		getRemainingDuration().then(remain => {
			if(remain <= 0){
				Modal.warning({
					wrapClassName:'root-modal-confirm',
					title: t('confirm.title'),
					icon: <ModalWarning.Icon/>,
					content: t("order.remaining_duration_warning"),
					okText: t('confirm.ok'),
					centered: true
				})
			}
			console.log('remain', remain)
		})
	}
	useEffect(() => {
		if(i18n.language){
			if(i18n.language == 'multiple'){
				const lang = localStorage.getItem('ai-human-lang') || (navigator.language.toLocaleLowerCase().indexOf('cn') != -1 ? 'zh-CN' : 'en-US')
				i18n.changeLanguage(lang).catch(console.log)
				return;
			}
		}
		if (i18n && i18n.language == 'zh-CN') {
			dayjs.locale('zh-cn');
		}else{
			dayjs.locale('en')
		}
		initRemainingDuration()
		globalConfig.i18n = i18n.language
		// i18n.changeLanguage(i18n).then(()=>console.log('change lang to ',i18n))
	}, [i18n.language])

	return (<ConfigProvider
		locale={i18n?.language?.toString() == 'zh-CN' ? zhCN : undefined}
		theme={{
			token: {
				borderRadius: 4,
			},
		}}
	>
		<DocumentTitle title={t('AppTitle')}/>
		<App className={`lang-${i18n.language}`}>
			<Suspense fallback={<Loader/>}>
				<RouterProvider future={{v7_startTransition: true}} router={router}/>
			</Suspense>
		</App>
	</ConfigProvider>)
}

export default AppRouter;