

type TCPlayerEvents = 'play' // 已经开始播放，调用 play() 方法或者设置了 autoplay 为 true 且生效时触发，这时 paused 属性为 false。
	| 'playing' // 因缓冲而暂停或停止后恢复播放时触发，paused 属性为 false 。通常用这个事件来标记视频真正播放，play 事件只是开始播放，画面并没有开始渲染。
	| 'loadstart' // 开始加载数据时触发。
	| 'durationchange' // 视频的时长数据发生变化时触发。
	| 'loadedmetadata' // 已加载视频的 metadata。
	| 'loadeddata' // 当前帧的数据已加载，但没有足够的数据来播放视频的下一帧时，触发该事件。
	| 'progress' // 在获取到媒体数据时触发。
	| 'canplay' // 当播放器能够开始播放视频时触发。
	| 'canplaythrough' // 当播放器预计能够在不停下来进行缓冲的情况下持续播放指定的视频时触发。
	| 'error' // 视频播放出现错误时触发。
	| 'pause' // 暂停时触发。
	| 'blocked' // 自动播放被浏览器阻止时触发。（原 2005 回调事件统一合并到 blocked 事件中）。
	| 'ratechange' // 播放速率变更时触发。
	| 'seeked' // 搜寻指定播放位置结束时触发。
	| 'seeking' // 搜寻指定播放位置开始时触发。
	| 'timeupdate' // 当前播放位置有变更，可以理解为 currentTime 有变更。
	| 'volumechange' // 设置音量或者 muted 属性值变更时触发。
	| 'waiting' // 播放停止，下一帧内容不可用时触发。
	| 'ended' // 视频播放已结束时触发。此时 currentTime 值等于媒体资源最大值。
	| 'resolutionswitching' // 清晰度切换进行中。
	| 'resolutionswitched' // 清晰度切换完毕。
	| 'fullscreenchange' //全屏状态切换时触发。
	| 'webrtcevent' // 播放 webrtc 时的事件集合。
	| 'webrtcstats' // 播放 webrtc 时的统计数据。
	| 'webrtcfallback' // 播放 webrtc 时触发降级。

declare type TCPlayerInstance = {
	//监听事件。
	on: (event: TCPlayerEvents, callback: () => void) => void;
	// 取消监听事件。
	off: (event: TCPlayerEvents, callback: () => void) => void;
	// 监听事件，事件处理函数最多只执行1次。
	one: (event: TCPlayerEvents, callback: () => void) => void;
	// 设置播放地址。
	src: (url: string) => void;
	// 设置播放器初始化完成后的回调。
	ready: (callback: () => void) => void;
	play: () => void;
	pause: () => void;
	unload: () => void;
	//获取或设置播放器是否静音。
	muted: (mute: boolean) => boolean | void;
	//获取或设置播放器音量。
	volume: (percent: number) => number | void;
	// 获取或设置播放倍速。
	playbackRate: (percent: number) => number | void;
	//获取当前播放时间点，或者设置播放时间点，该时间点不能超过视频时长。
	currentTime: (seconds?: number) => number;
	//获取视频时长。
	duration: () => number;
	// 销毁播放器。
	dispose: () => number;
};

declare function TCPlayer(container: HTMLVideoElement | string, options: any): TCPlayerInstance;

declare module 'tcplayer.js' {
	export default TCPlayer;
}